@@ -37,24 +37,25 @@ def get_errors_fails(report_path: str):
 
 def mark_complete(task_id: str, message=None):
     data = {
-            'task_id': task_id,
-            'user_id': user_id,
+            'taskId': task_id,
+            'userId': user_id,
+            'verified': True
             }
     if message:
         data['message'] = message
 
-    r = requests.post(url_api, headers=headers, data=json.dumps(data))
+    r = requests.post(url_endpoint, headers=headers, data=json.dumps(data))
     assert r.status_code == 200
 
 def mark_incomplete(task_id: str, message=None):
     data = {
-            'task_id': task_id,
-            'user_id': user_id,
-            'complete': False
+            'taskId': task_id,
+            'userId': user_id,
+            'verified': False
             }
     if message:
         data['message'] = message
 
-    r = requests.post(url_api, headers=headers, data=json.dumps(data))
-
+    r = requests.post(url_endpoint, headers=headers, data=json.dumps(data))
+    
     assert r.status_code == 200
